<?php
/*
Plugin Name: LDAP Authentication Plug-in
Plugin URI: http://wpmuldap.frozenpc.net
Description: A plugin to override the core Wordpress MU authentication method so as to use an LDAP server for authentication.  
Version: 2.8.4
Author: Alistair Young (http://www.weblogs.uhi.ac.uk/sm00ay/), 
	Patrick Cavit (http://patcavit.com), 
	Hugo Salgado (http://hugo.vulcano.cl), 
	Alex Barker (http://www.callutheran.edu), 
	Dexter Arver, 
	Sean Wedig (http://www.thecodelife.net), 
	Aaron Axelsen (http://www.frozenpc.net)
*/

// Includes
require_once("ldap/lib/ldap_ro.php");

// methods for supporting site-admin configuration of the plugin
require_once("ldap/lib/wpmu_ldap_admin.functions.php");
require_once("ldap/lib/wpmu_ldap_adduser.functions.php");

add_action('admin_head', 'ldapShowOptionsCss');
add_action('admin_menu', 'ldap_addmenu');
add_action('admin_menu', 'ldap_addmenuuser');
add_action('admin_menu', 'wpmuRemoveAddNewMenu');

// perform these filters, actions, and WP function overrides only if LDAP-
//  authentication is enabled; this is to cut down on parsing of this code when
//  it doesn't apply 
if (get_site_option("ldapAuth")) { 

	// Add radio buttons for switching individual users between LDAP accounts and non-LDAP accounts
	add_action('edit_user_profile', 'wpmuUserFormLdapOption');
	add_action('edit_user_profile_update', 'wpmuUserFormLdapOptionUpdate');

	// *** End Admin Config Functions *** //

	// *** Begin User Auth Functions *** //
	// disable public signup if configured to do so  
	if (get_site_option('ldapDisableSignup')) {
		add_action('signup_header', 'wpmuLdapDisableSignup');
		add_action('login_head', 'wpmuLdapDisableSignupMessage');
	}

	// only include them if it's active, so as to cut down on continual parsing of the code 
	require_once("ldap/lib/wpmu_ldap.functions.php");

	// Authentication filters
	add_action('authenticate', 'wpmuLdapUsernamePasswordAuthenticate', 25, 3);
	if (get_site_option('ldapSSOEnabled')) add_action('authenticate', 'wpmuLdapSSOAuthenticate', 40, 3);

	// disable only for ldap accounts
	add_filter('show_password_fields', 'wpmuLdapDisableLdapPassword');

	// disable default add user box	
	add_filter('show_adduser_fields', 'wpmuLdapDisableShowUser');

}
